<?php
if (!defined('ABSPATH')) exit; // Exit if accessed directly

/*
Plugin Name: Attachment Tab For Woocommerce
Plugin URI: https://www.persianscript.ir
Description: Super easy way to attach unlimited number of files for WooCommerce products.
Author: پرشین اسکریپت
Version: 1.2.4
WP Requires at least: 5.6+
Author URI: https://www.persianscript.ir
Text domain: bwl-atfc
*/

class BWL_ATFC
{

    function __construct()
    {

        /*--- PLUGIN COMMON CONSTANTS ---*/
        define("BWL_ATFC_PLUGIN_TITLE", 'Attachment Tab For Woocommerce');
        define("BWL_ATFC_PLUGIN_ROOT", 'attachment-tab-for-woocommerce');
        define("BWL_ATFC_PLUGIN_DIR", plugins_url() . '/attachment-tab-for-woocommerce/');
        define("BWL_ATFC_PLUGIN_VERSION", '1.2.4');
        define("BWL_ATFC_PLUGIN_UPDATER_SLUG", plugin_basename(__FILE__)); // change plugin current version in here.
        define("BWL_ATFC_PLUGIN_PATH", __DIR__);

        define('BWL_ATFC_INSTALLATION_TAG', 'atfc_installation_' . str_replace('.', '_', BWL_ATFC_PLUGIN_VERSION));

        // Autoupdate and verfication constants.
        define("BWL_ATFC_PLUGIN_ROOT_FILE", 'attachment-tab-for-woocommerce.php');
        define("BWL_ATFC_CC_ID", "16192483");
        define("BWL_ATFC_CC_URL", "https://1.envato.market/atfc-wp"); // Plugin codecanyon URL.
        define("BWL_ATFC_SUPPORT_URL", "https://codecanyon.net/item/attachment-tab-for-woocommerce/16192483/support/contact"); // support link
        define("BWL_ATFC_YOUTUBE_PLAYLIST", "https://www.youtube.com/playlist?list=PLxYTuQlgnCLqYdAlQC_QIEihKqci-UThC"); // YouTube link
        define("BWL_ATFC_DOC_URL", 'https://projects.bluewindlab.net/wpplugin/atfc/doc'); // doc link.
        define("BWL_ATFC_VERIFIED", get_option('atfc_purchase_verified')); // purchase verification status.

        // Call Immediatly Initialized.     
        require_once BWL_ATFC_PLUGIN_PATH . '/includes/bwl-atfc-check-compatibility.php';

        $bwl_atfc_compatibily_status = atfc_compatibily_status();

        if ($bwl_atfc_compatibily_status == 1) {

            //Since: Version 1.1.0
            $this->includeFiles();

            //@Description: Load Frontend & Admin Styles & Scripts.
            add_action('wp_enqueue_scripts', [$this, 'atfcFrontendScripts']);
            add_action('admin_enqueue_scripts', [$this, 'atfcAdminScripts']);
            add_action('plugins_loaded', [$this, 'atfcLoadTranslationFile']);
        } else {

            $this->atfcCompatibilyNotice();
        }
    }


    function displayAtfcParentRequirementNotice()
    {
        echo '<div class="notice notice-error">
                    <p>
                    <span class="dashicons dashicons-info bwl_plugins_notice_text--danger"></span> 
                    You need to download & install <b><a href="http://downloads.wordpress.org/plugin/woocommerce.zip" target="_blank">WooCommerce Plugin</a></b> to use <b>' . BWL_ATFC_PLUGIN_TITLE . '</b> !
                    </p>
                </div>';
    }

    public function atfcCompatibilyNotice()
    {
        add_action('admin_notices', [$this, 'displayAtfcParentRequirementNotice']);
    }

    public function includeFiles()
    {

        /*--- INTEGRATE SHORTCODE   ---*/

        require_once BWL_ATFC_PLUGIN_PATH . '/includes/db/AtfcDbSettings.php';
        require_once BWL_ATFC_PLUGIN_PATH . '/includes/atfc-helpers.php';
        require_once BWL_ATFC_PLUGIN_PATH . '/includes/atfc-download-counter.php';
        require_once BWL_ATFC_PLUGIN_PATH . '/includes/shortcode/atfc-shortcodes.php';

        $atfc_options = get_option('atfc_options');

        $atfc_custom_title_status = 0;

        if (isset($atfc_options['atfc_custom_title_status']) && $atfc_options['atfc_custom_title_status'] == 1) {

            $atfc_custom_title_status = 1;
        }

        if (is_admin()) {

            // Plugin Metainfo.
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/metainfo/AtfcMetaInfo.php';

            require_once BWL_ATFC_PLUGIN_PATH . '/includes/atfc-cmb-framework/atfc-custom-meta-box.php';
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/atfc-custom-column.php';

            if ($atfc_custom_title_status == 1) {
                require_once BWL_ATFC_PLUGIN_PATH . '/includes/atfc-custom-media-column.php';
            }

            require_once BWL_ATFC_PLUGIN_PATH . '/includes/atfc-quick-edit.php';

            // Options Panel.
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/option-panel/options_panel_menu.php';
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/option-panel/options_panel_settings.php';

            // Download Report Panel.
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/option-panel/download_report_settings.php';

            // Auto Updater Scripts.
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/autoupdater/WpAutoUpdater.php';
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/autoupdater/installer.php';
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/autoupdater/updater.php';
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/autoupdater/atfc-update-notifier.php';
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/autoupdater/plugin_purchase_verify.php';

            // Admin Notice.
            require_once BWL_ATFC_PLUGIN_PATH . '/includes/noticebox/AtfcAdminNotice.php';
        } else {

            add_filter('woocommerce_product_tabs', [$this, 'bwl_product_atfc_tab']);
        }
    }

    public function atfcFrontendScripts()
    {

        $atfc_options = get_option('atfc_options');

        if (!isset($atfc_options['atfc_load_font_awesome']) || $atfc_options['atfc_load_font_awesome'] == 1) {
            wp_enqueue_style('font-awesome-5', plugins_url('libs/font-awesome/font-awesome.min.css', __FILE__), [], BWL_ATFC_PLUGIN_VERSION);
            wp_enqueue_style('font-awesome-5-shims', plugins_url('libs/font-awesome/v4-shims.min.css', __FILE__), [], BWL_ATFC_PLUGIN_VERSION);
        }

        wp_enqueue_style('atfc-frontend', plugins_url('assets/styles/frontend.css', __FILE__), [], BWL_ATFC_PLUGIN_VERSION);

        if (is_rtl()) {
            wp_enqueue_style('atfc-rtl', plugins_url('assets/styles/frontend_rtl.css', __FILE__), [], BWL_ATFC_PLUGIN_VERSION);
        }

        wp_enqueue_script('atfc-frontend', plugins_url('assets/scripts/frontend.js', __FILE__), ['jquery'], BWL_ATFC_PLUGIN_VERSION, TRUE);
    }

    // @Load Only Admin Panel Scripts.
    // @Description: Load Plugin Admin Panel Required Custom JS & CSS Files.
    // @Since: version 1.0.0

    public function atfcAdminScripts($hook)
    {
        wp_register_style('atfc-jquery-ui', plugins_url('libs/jqueryui/flick/jquery-ui-1.9.0.custom.min.css', __FILE__), [], BWL_ATFC_PLUGIN_VERSION);
        wp_register_style('atfc-datatables', plugins_url('libs/jquery-datatables/styles/jquery.dataTables.css', __FILE__), ['atfc-jquery-ui']);
        wp_register_style('atfc-admin', plugins_url('assets/styles/admin.css', __FILE__), ['atfc-datatables']);
        wp_enqueue_style('atfc-admin');

        // Register Data Table & It's required codes.
        wp_register_script('atfc-datatable', plugins_url('libs/jquery-datatables/scripts/jquery.dataTables.min.js', __FILE__), ['jquery'], BWL_ATFC_PLUGIN_VERSION, TRUE);
        wp_enqueue_script('atfc-admin', plugins_url('assets/scripts/admin.js', __FILE__), ['jquery', 'jquery-ui-core', 'jquery-ui-datepicker', 'jquery-ui-dialog', 'atfc-datatable'], BWL_ATFC_PLUGIN_VERSION, TRUE);

        wp_localize_script(
            'atfc-admin',
            'AtfcAdminData',
            [
                'atfc_text_loading' => esc_attr__('Loading .....', 'bwl-atfc'),
                'atfc_pvc_required_msg' => esc_attr__('Purchase code is required!', 'bwl-atfc'),
                'atfc_pvc_success_msg' => esc_attr__('Purchase code verified. Reloading window in 3 seconds.', 'bwl-atfc'),
                'atfc_pvc_failed_msg' => esc_attr__('Unable to verify purchase code. Please try again or contact support team.', 'bwl-atfc'),
                'atfc_pvc_remove_msg' => esc_attr__('Are you sure to remove the license info?', 'bwl-atfc'),
                'atfc_pvc_removed_msg' => esc_attr__('Purchase code removed. Reloading window in 3 seconds.', 'bwl-atfc'),
                'product_id' => BWL_ATFC_CC_ID,
                'installation' => get_option(BWL_ATFC_INSTALLATION_TAG)
            ]
        );
    }


    public function bwl_product_atfc_tab($tabs)
    {

        global $product;

        $atfc_options = get_option('atfc_options');

        $atfc_tab_title = esc_html__("Attachment ", 'bwl-atfc');

        if (isset($atfc_options['atfc_tab_title']) && $atfc_options['atfc_tab_title'] != "") {

            $atfc_tab_title = trim($atfc_options['atfc_tab_title']);
        }

        $atfc_tab_position = 100; // Set Attachment tab in last position.

        if (isset($atfc_options['atfc_tab_position']) && is_numeric($atfc_options['atfc_tab_position'])) {

            $atfc_tab_position =  trim($atfc_options['atfc_tab_position']);
        }


        $atfc_display_status = get_post_meta($product->get_id(), 'atfc_display_status', true);

        if (isset($atfc_display_status) && $atfc_display_status == 1) {

            return $tabs;
        }

        // Count total number of attachments.

        //Lets count the total number of attachments.
        $atfc_attachments = get_post_meta($product->get_id(), 'atfc_attachments', true);

        $atfc_auto_hide_tab = 0;

        if (isset($atfc_options['atfc_auto_hide_tab']) && $atfc_options['atfc_auto_hide_tab'] == 1) {

            $atfc_auto_hide_tab = 1;
        }

        // Global Attachment Status.

        if (isset($atfc_options['atfc_global_attachment_status']) && $atfc_options['atfc_global_attachment_status'] == 1) {

            $atfc_attachments = atfc_get_global_attachments($atfc_attachments);
        }


        if ($atfc_auto_hide_tab == 1) {

            if (empty($atfc_attachments)) {

                return $tabs;
            }
        }

        // Tab Custom Title.

        $atfc_tab_custom_title = get_post_meta($product->get_id(), 'atfc_tab_custom_title', true);

        if (!empty($atfc_tab_custom_title)) {

            $atfc_tab_title = $atfc_tab_custom_title;
        }


        // Attachment View Type.

        $atfc_view_type = 'box_view';

        if (isset($atfc_options['atfc_view_type']) && $atfc_options['atfc_view_type'] == 'list_view') {
            $atfc_view_type = 'list_view';
        }

        // If everything alright, we are going to generate attachment tab content.


        $tabs['bwl_atfc_tab'] = [
            'title' => $atfc_tab_title,
            'priority' => $atfc_tab_position, // Always display at the end of tab :)
            'callback' => [$this, 'bwl_atfc_tab_content'],
            'content' => do_shortcode('[bwl_atfc product_id="' . $product->get_id() . '" atfc_view_type="' . $atfc_view_type . '" /]')
        ];

        return $tabs;
    }

    public function bwl_atfc_tab_content($key, $tab)
    {
        // allow shortcodes to function
        $content = str_replace(']]>', ']]&gt;', $tab['content']);
        echo apply_filters('woocommerce_custom_product_tabs_atfc_content', $content, $tab);
    }

    /*-- TRANSLATION FILE --*/

    function atfcLoadTranslationFile()
    {
        load_plugin_textdomain('bwl-atfw', FALSE, dirname(plugin_basename(__FILE__)) . '/lang/');
    }
}

/*--- Initialization ---*/

function initBwlAtfc()
{
    new BWL_ATFC();
}

add_action('init', 'initBwlAtfc');
