<?php


/*------------------------------  Custom Meta Box Section ---------------------------------*/

class ATFC_Meta_Box
{

    public $custom_fields;

    function __construct($custom_fields)
    {

        $this->custom_fields  = $custom_fields; //Set custom field data as global value.

        add_action('add_meta_boxes', array(&$this, 'atfc_metaboxes'));

        add_action('save_post_product', array(&$this, 'save_atfc_meta_box_data'));
    }


    //Custom Meta Box.

    function atfc_metaboxes()
    {

        $bwl_cmb_custom_fields = $this->custom_fields;

        // First parameter is meta box ID.
        // Second parameter is meta box title.
        // Third parameter is callback function.
        // Last paramenter must be same as post_type_name

        add_meta_box(
            $bwl_cmb_custom_fields['meta_box_id'],
            $bwl_cmb_custom_fields['meta_box_heading'],
            array(&$this, 'show_meta_box'),
            $bwl_cmb_custom_fields['post_type'],
            $bwl_cmb_custom_fields['context'],
            $bwl_cmb_custom_fields['priority']
        );
    }

    function show_meta_box($post)
    {

        $bwl_cmb_custom_fields = $this->custom_fields;

        foreach ($bwl_cmb_custom_fields['fields'] as $custom_field) :

            $field_value = get_post_meta($post->ID, $custom_field['id'], true);

?>

<?php if ($custom_field['type'] == 'text') : ?>

<p class="bwl_cmb_row">
  <label for="<?php echo $custom_field['id'] ?>"><?php echo $custom_field['title'] ?> </label>
  <input type="<?php echo $custom_field['type'] ?>" id="<?php echo $custom_field['id'] ?>"
    name="<?php echo $custom_field['name'] ?>" class="<?php echo $custom_field['class'] ?>"
    value="<?php echo esc_attr($field_value); ?>" />
</p>

<?php endif; ?>

<?php if ($custom_field['type'] == 'select') : ?>

<?php

                $values = get_post_custom($post->ID);


                $selected = isset($values[$custom_field['name']]) ? esc_attr($values[$custom_field['name']][0]) : $custom_field['default_value'];

                ?>

<p class="bwl_cmb_row">
  <label for="<?php echo $custom_field['id'] ?>"><?php echo $custom_field['title'] ?> </label>
  <select name="<?php echo $custom_field['name'] ?>" id="<?php echo $custom_field['id'] ?>">

    <option value="" selected="selected">- Select -</option>

    <?php foreach ($custom_field['value'] as $key => $value) : ?>
    <option value="<?php echo $key ?>" <?php selected($selected, $key); ?>><?php echo $value; ?></option>
    <?php endforeach; ?>

  </select>

  <?php if (isset($custom_field['desc']) && $custom_field['desc'] != "") { ?>
  <i><?php echo $custom_field['desc']; ?></i>
  <?php } ?>
</p>

<?php endif; ?>

<?php if ($custom_field['type'] == 'atfc_repeatable') : ?>

<p class="bwl_cmb_row bwl_cmb_db">
  <label for="<?php echo $custom_field['id'] ?>"><?php echo $custom_field['title'] ?>: </label>
  <?php if (isset($custom_field['desc']) && $custom_field['desc'] != "") : ?>
  <small class="small-text"><?php echo $custom_field['desc']; ?></small>
  <?php endif; ?>
</p>

<ul class="bwl_cmb_repeat_field_container">

  <?php

                    $i = 0;

                    $field_value = get_post_meta($post->ID, $custom_field['id'], true);


                    if (!empty($field_value) && is_array($field_value)) {

                        foreach ($field_value as $data) {

                            // Need attachment ID;

                            //                                $attachment_post_id = $data;
                            //
                            //                                if( is_numeric($data) ) {
                            //                                    $get_bkb_attachment_url = home_url() . '/wp-content/uploads/' . get_post_meta( $attachment_post_id, '_wp_attached_file', true);
                            //                                } else {
                            //                                    $get_bkb_attachment_url = $data;
                            //                                }


                    ?>

  <li class="bwl_cmb_repeat_row" data-row_count="<?php echo $i; ?>">
    <span class="label"><?php echo $custom_field['label_text']; ?></span>
    <input id="<?php echo $custom_field['id'] . '_' . $i; ?>_url" class="img-path" type="text"
      name="<?php echo $custom_field['name'] . '[' . $i . '][atfc_url]' ?>" value="<?php echo $data['atfc_url']; ?>" />
    <input id="<?php echo $custom_field['id'] . '_' . $i; ?>_id" type="hidden"
      name="<?php echo $custom_field['name'] . '[' . $i . '][atfc_id]' ?>" value="<?php echo $data['atfc_id']; ?>" />
    <input id="upload_<?php echo $custom_field['id'] . '_' . $i; ?>_button" type="button"
      class="button atfc_cmb_upload_file" value="<?php esc_html_e('Upload', 'tie') ?>"
      data-parent_field="<?php echo $custom_field['id']; ?>" data-row_count="<?php echo $i; ?>" />
    <div class="clear"></div>
    <a class="atfc_delete_row"
      title="<?php esc_html_e('Delete', 'bwl-atfc') ?>"><?php esc_html_e('Delete', 'bwl-atfc') ?></a>
  </li>

  <?php

                            $i++;
                        }
                    }

                    ?>
</ul>

<input id="atfc_add_new_row" type="button" class="button" value="<?php echo $custom_field['btn_text']; ?>"
  data-delete_text="<?php esc_html_e('Delete', 'bwl-atfc') ?>"
  data-upload_text="<?php esc_html_e('Upload', 'bwl-atfc') ?>"
  data-field_type="<?php echo $custom_field['field_type'] ?>" data-field_name="<?php echo $custom_field['name'] ?>"
  data-label_text="<?php echo $custom_field['label_text']; ?>">
<input type="hidden" name="atfc_rows" id="atfc_rows" value="<?php echo $i ?>" />

<?php endif; ?>

<?php

        endforeach;
    }

    function save_atfc_meta_box_data($id)
    {

        global $post;

        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {

            return $id;
        } else {

            $bkb_meta_custom_fields = $this->custom_fields;

            $atfc_excluded_fileds = array('atfc_attachments');

            foreach ($bkb_meta_custom_fields['fields'] as $custom_field) {

                if (isset($_POST[$custom_field['name']])) {

                    // Updated in version 1.1.2

                    if (!in_array($custom_field['name'], $atfc_excluded_fileds)) {

                        update_post_meta($id, $custom_field['name'], sanitize_text_field($_POST[$custom_field['name']]));
                    }
                }
            }


            // Repeatable Fields Data Saving In Here.
            // Introduced in version 1.1.2

            if (isset($_POST['atfc_rows']) && $_POST['atfc_rows'] == 0) {

                delete_post_meta($id, 'atfc_attachments');
            } else if (isset($_POST['atfc_attachments'])) {

                $atfc_clean_attachments = sanitize_meta('atfc_attachments', $_POST['atfc_attachments'], 'atfc');

                update_post_meta($id, 'atfc_attachments',  $atfc_clean_attachments);
            } else {
            }
        }
    }
}

function cb_sanitize_atfc_attachments($atfc_attachments)
{

    if (empty($atfc_attachments))
        return $atfc_attachments;

    $atfc_clean_attachments = array();

    foreach ($atfc_attachments as $attachments) {
        $atfc_clean_attachments[] = array(
            'atfc_url' => esc_url($attachments['atfc_url']),
            'atfc_id' => $attachments['atfc_id']
        );
    }

    return $atfc_clean_attachments;
}

add_filter('sanitize_atfc_meta_atfc_attachments', 'cb_sanitize_atfc_attachments');

// Register Custom Meta Box For BWL Pro Related Post Manager

function atfc_cmb_init()
{

    // Start Coding From here.

    wp_enqueue_script('media-upload');
    wp_enqueue_script('thickbox');
    wp_enqueue_style('thickbox');

    wp_register_script('atfc-cmb-admin-main', plugins_url(BWL_ATFC_PLUGIN_ROOT . '/includes/atfc-cmb-framework/admin/js/atfc_cmb.js'), array('jquery', 'jquery-ui-core', 'jquery-ui-sortable'), BWL_ATFC_PLUGIN_VERSION, false);
    wp_register_style('atfc-cmb-admin-style', plugins_url(BWL_ATFC_PLUGIN_ROOT . '/includes/atfc-cmb-framework/admin/css/atfc_cmb.css'), array(), BWL_ATFC_PLUGIN_VERSION, 'all');

    wp_enqueue_script('atfc-cmb-admin-main');
    wp_enqueue_style('atfc-cmb-admin-style');

    $atfc_custom_post_types = array('product');

    foreach ($atfc_custom_post_types as $post_types_key => $post_types_value) {

        // Related KB Posts Custom Meta Box.

        $atfc_display_fields = array(

            'meta_box_id'           => 'cmb_atfc_display_settings', // Unique id of meta box.
            'meta_box_heading'  => 'Attachment Tab Display Settings', // That text will be show in meta box head section.
            'post_type'               => $post_types_value, // define post type. go to register_post_type method to view post_type name.        
            'context'                   => 'normal',
            'priority'                    => 'high',
            'fields'                       => array(
                'atfc_display_status'  => array(
                    'title'      => esc_html__('Hide Attachment Tab?  ', 'bwl-atfc'),
                    'id'         => 'atfc_display_status',
                    'name'    => 'atfc_display_status',
                    'type'      => 'select',
                    'value'     => array(
                        '0' => esc_html__('No', 'bwl-atfc'),
                        '1' => esc_html__('yes', 'bwl-atfc')
                    ),
                    'default_value' => 0,
                    'class'      => 'widefat'
                ),
                'atfc_tab_custom_title'  => array(
                    'title'      => esc_html__('Tab Custom Title ', 'bwl-atfc'),
                    'id'         => 'atfc_tab_custom_title',
                    'name'    => 'atfc_tab_custom_title',
                    'type'      => 'text',
                    'value'     => '',
                    'default_value' => '',
                    'class'      => ''
                )

            )
        );


        new ATFC_Meta_Box($atfc_display_fields);

        // Custom Attachment Fields.
        //@introduced in version 1.1.2

        $atfc_attachment_fields = array(

            'meta_box_id'           => 'cmb_atfc_attachment_settings', // Unique id of meta box.
            'meta_box_heading'  => esc_html__('Product Attachment Settings', 'bwl-atfc'), // That text will be show in meta box head section.
            'post_type'               => $post_types_value, // define post type. go to register_post_type method to view post_type name.        
            'context'                   => 'normal',
            'priority'                    => 'high',
            'fields'                       => array(

                'atfc_attachments'  => array(
                    'title'      => esc_html__('Add Files', 'bwl-atfc'),
                    'id'         => 'atfc_attachments',
                    'name'    => 'atfc_attachments',
                    'type'      => 'atfc_repeatable',
                    'value'     => '',
                    'default_value' => '',
                    'class'      => 'widefat',
                    'btn_text' => esc_html__('Add New File', 'bwl-atfc'),
                    'label_text' => esc_html__('File: ', 'bwl-atfc'),
                    'field_type' => 'upload'
                )
            )
        );


        new ATFC_Meta_Box($atfc_attachment_fields);
    }
}


// META BOX START EXECUTION FROM HERE.

add_action('admin_init', 'atfc_cmb_init');