<?php

/* ------------------------------  Custom Column Section --------------------------------- */

function atfc_media_field_custom_items($form_fields, $post)
{

    $atfc_media_custom_title = get_post_meta($post->ID, 'atfc_media_custom_title', true);
    $atfc_global_item = (bool) get_post_meta($post->ID, 'atfc_global_item', true);




    $form_fields['atfc_media_custom_title'] = [
        'label' => esc_html__('Custom Title', 'bwl-atfc') . ':',
        'input' => 'html',
        'html' => '<label for="attachments-' . $post->ID . '-atfc_media_custom_title"> ' .
            '<input type="text" id="attachments-' . $post->ID . '-atfc_media_custom_title" class="widefat" name="attachments[' . $post->ID . '][atfc_media_custom_title]" value="' . $atfc_media_custom_title . '"/>',
        'value' => $atfc_media_custom_title,
        'helps' => esc_html__('This custom title will display in WooCommerce attachment tab download items.', 'bwl-atfc'),
    ];

    $form_fields['atfc_global_item'] = [
        'label' => esc_html__('Mark As Global Attachment ?', 'bwl-atfc'),
        'input' => 'html',
        'html' => '<label for="attachments-' . $post->ID . '-atfc_global_item"> ' .
            '<input type="checkbox" id="attachments-' . $post->ID . '-atfc_global_item" name="attachments[' . $post->ID . '][atfc_global_item]" value="1"' . ($atfc_global_item ? ' checked="checked"' : '') . ' /> Yes</label>  ',
        'value' => $atfc_global_item
    ];

    return $form_fields;
}

add_filter('attachment_fields_to_edit', 'atfc_media_field_custom_items', 10, 2);

/**
 * Save values of custom title
 *
 */

function atfc_media_field_custom_items_save($post, $attachment)
{

    if (isset($attachment['atfc_media_custom_title'])) {
        update_post_meta($post['ID'], 'atfc_media_custom_title', sanitize_text_field(trim($attachment['atfc_media_custom_title'])));
    }

    if (isset($attachment['atfc_global_item'])) {
        update_post_meta($post['ID'], 'atfc_global_item', trim($attachment['atfc_global_item']));
    }

    return $post;
}

add_filter('attachment_fields_to_save', 'atfc_media_field_custom_items_save', 10, 2);

// After manage text we need to add "custom_post_type" value.

add_filter('manage_media_columns', 'atfc_custom_media_column_header');

function atfc_custom_media_column_header($columns)
{

    return array_merge(
        $columns,
        [
            'atfc_media_custom_title' => esc_html__('Custom Title', 'bwl-atfc'),
            'atfc_global_item' => esc_html__('Global Attachment', 'bwl-atfc') . ' <a href="https://xenioushk.github.io/docs-wp-plugins/atfc/index.html#global_attachment_to_all_product"><span class="dashicons dashicons-info bwl_plugins_notice_text--success" title="Learn more about global attachments." target="_blank"></span></a>'
        ]
    );
}


// After manage text we need to add "custom_post_type" value.

add_action('manage_media_custom_column', 'atfc_display_custom_media_column', 10, 1);

function atfc_display_custom_media_column($column)
{

    // Add A Custom Image Size For Admin Panel.

    global $post;

    switch ($column) {

        case 'atfc_media_custom_title':

            $atfc_media_custom_title = get_post_meta($post->ID, 'atfc_media_custom_title', true);

            $atfc_media_custom_title_string = (empty($atfc_media_custom_title)) ?  '' : trim($atfc_media_custom_title);

            echo '<div id="atfc_media_custom_title-' . $post->ID . '" >' . $atfc_media_custom_title_string . '</div>';

            break;

        case 'atfc_global_item':

            $atfc_global_item = (bool) get_post_meta($post->ID, 'atfc_global_item', true);

            if ($atfc_global_item == 1) {
                $atfc_global_item_status = "<span class='dashicons dashicons-yes bwl_plugins_notice_text--success' title='" . esc_attr__('Yes', 'bwl-atfc') . "'></span>";
            } else {
                $atfc_global_item_status = "<span class='dashicons dashicons-no bwl_plugins_notice_text--danger' title='" . esc_attr__('No', 'bwl-atfc') . "'></span>";
            }

            echo '<div id="atfc_global_item-' . $post->ID . '" >' . $atfc_global_item_status . '</div>';

            break;
    }
}
