<?php


if (!function_exists('bwllog')) {
    function bwllog($message, $clean = false)
    {
        if (is_array($message)) {
            $message = json_encode($message);
        }

        $existing_logs = "";

        $log_file = plugin_dir_path(__FILE__) . "custom_logs.log";

        if ($clean == false) {
            $existing_logs = file_get_contents($log_file);
        }
        $new_log = date('Y-m-d h:i:s') . " :: " . $message . "\n" . $existing_logs;

        file_put_contents($log_file, $new_log);
    }
}

if (!function_exists('getRenewalDaysLeft')) {

    function getRenewalDaysLeft($renewalDate)
    {

        // $renewalDate = "2024-01-30T01:51:19+11:00";

        // Convert the renewal date to a DateTime object
        $renewalDateTime = new DateTime($renewalDate);

        // Get the current date
        $currentDate = new DateTime();

        // Compare the renewal date with the current date
        if ($renewalDateTime < $currentDate) {
            // Renewal date has expired

            return [
                'status' => 0,
                'msg' => "Renewal date has expired"
            ];
        } else {
            // Calculate the difference between the renewal date and the current date
            $interval = $currentDate->diff($renewalDateTime);
            $daysLeft = $interval->days;

            return [
                'status' => 1,
                'msg' => "$daysLeft days left for renewal"
            ];
        }
    }
}

function getAtfcLicenseInfo()
{

    $purchaseVerified = get_option('atfc_purchase_verified') ?? 0;
    $purchaseInfo = get_option('atfc_purchase_info') ?? [];

    $pluginLicenseData = [
        'title' => BWL_ATFC_PLUGIN_TITLE,
        'status' => $purchaseVerified, // 1= active, 0=not active, 2=no license reqruired.
        'info' => $purchaseInfo,
        'pluginId' => BWL_ATFC_CC_ID,
        'supportLink' =>  BWL_ATFC_SUPPORT_URL
    ];

    return $pluginLicenseData;
}

if (!function_exists('bwlApiUrl')) {

    function bwlApiUrl()
    {
        $baseUrl = get_home_url();
        if (strpos($baseUrl, "localhost") != false) {
            return "http://localhost/bwl_api/";
        } elseif (strpos($baseUrl, "staging.bluewindlab.com") != false) {
            return "https://staging.bluewindlab.com/bwl_api/";
        } else {
            return "https://api.bluewindlab.net/";
        }
    }
}

if (!function_exists('bwlBeautifyDate')) {

    function bwlBeautifyDate($date)
    {

        $splitDate = explode("T", $date);

        $rearrangeDate = explode("-", $splitDate[0]);

        return $rearrangeDate[2] . "-" . $rearrangeDate[1] . "-" . $rearrangeDate[0];
    }
}


function atfc_attachment_unique_key($array, $keyname)
{

    $new_array = [];
    foreach ($array as $key => $value) {

        if (!isset($new_array[$value[$keyname]])) {
            $new_array[$value[$keyname]] = $value;
        }
    }
    $new_array = array_values($new_array);
    return $new_array;
}


function atfc_get_global_attachments($atfc_attachments = [])
{

    if (empty($atfc_attachments)) {
        $atfc_attachments = [];
    }

    // Get post that have the checkbox marked:
    $atfc_attachment_query = array(
        'post_type' => 'attachment',
        'post_status' => 'inherit',
        'posts_per_page' => -1,
        'meta_query' => array(
            array(
                'key' => 'atfc_global_item',
                'value' => 1
            )
        )
    );

    $atfc_global_attachments = new WP_Query($atfc_attachment_query);

    foreach ($atfc_global_attachments->posts as $attachment_data) {

        $atfc_attachments[] = array(
            'atfc_url' => wp_get_attachment_url($attachment_data->ID),
            'atfc_id' => $attachment_data->ID
        );
    }

    return atfc_attachment_unique_key($atfc_attachments, 'atfc_id');
}

/*------------------------------ Custom Scripts  ---------------------------------*/

function atfc_custom_scripts()
{

    $atfc_options = get_option('atfc_options');

    $atfc_pagination_status =  1;
    $atfc_items_per_page = 2;

    if (!isset($atfc_options['atfc_pagination_conditinal_fields']['enabled'])) {

        $atfc_pagination_status = 0;
    } else if (isset($atfc_options['atfc_pagination_conditinal_fields']['enabled']) && $atfc_options['atfc_pagination_conditinal_fields']['enabled'] == 'on') {

        if (isset($atfc_options['atfc_pagination_conditinal_fields']['atfc_items_per_page']) && $atfc_options['atfc_pagination_conditinal_fields']['atfc_items_per_page'] != "") {

            $atfc_items_per_page = $atfc_options['atfc_pagination_conditinal_fields']['atfc_items_per_page'];
        }
    } else {
        // do nothing ......
    }

    $atfc_display_counter = (isset($atfc_options['atfc_display_counter']) && $atfc_options['atfc_display_counter'] == "") ? 0 : 1;


    $atfc_custom_scripts = '<script type="text/javascript">';

    if ($atfc_display_counter == 1) {

        $atfc_custom_scripts .= 'var atfc_display_counter= ' . $atfc_display_counter . ';';
    }

    $atfc_custom_scripts .= 'var atfc_pagination_status = ' . $atfc_pagination_status . ',
                                                      atfc_items_per_page = ' . $atfc_items_per_page . ';';


    $atfc_custom_scripts .= '</script>';

    // Style section

    /*
     * @Initlization of all colors.
     */

    $atfc_box_bg = (isset($atfc_options['atfc_box_bg']) && $atfc_options['atfc_box_bg'] != "") ?  $atfc_options['atfc_box_bg'] : "#FFFFFF";
    $atfc_box_border_color = (isset($atfc_options['atfc_box_border_color']) && $atfc_options['atfc_box_border_color'] != "") ?  $atfc_options['atfc_box_border_color'] : "#DDDDDD";
    $atfc_box_icon_color = (isset($atfc_options['atfc_box_icon_color']) && $atfc_options['atfc_box_icon_color'] != "") ?  $atfc_options['atfc_box_icon_color'] : "#EEEEEE";


    $atfc_pag_box_bg = (isset($atfc_options['atfc_pag_box_bg']) && $atfc_options['atfc_pag_box_bg'] != "") ?  $atfc_options['atfc_pag_box_bg'] : "#FFFFFF";
    $atfc_pag_border_color = (isset($atfc_options['atfc_pag_border_color']) && $atfc_options['atfc_pag_border_color'] != "") ?  $atfc_options['atfc_pag_border_color'] : "#DDDDDD";
    $atfc_pag_box_text_color = (isset($atfc_options['atfc_pag_box_text_color']) && $atfc_options['atfc_pag_box_text_color'] != "") ?  $atfc_options['atfc_pag_box_text_color'] : "#000000";

    $atfc_pag_sel_box_bg = (isset($atfc_options['atfc_pag_sel_box_bg']) && $atfc_options['atfc_pag_sel_box_bg'] != "") ?  $atfc_options['atfc_pag_sel_box_bg'] : "#007ACB";
    $atfc_pag_sel_border_color = (isset($atfc_options['atfc_pag_sel_border_color']) && $atfc_options['atfc_pag_sel_border_color'] != "") ?  $atfc_options['atfc_pag_sel_border_color'] : "#DDDDDD";
    $atfc_pag_sel_box_text_color = (isset($atfc_options['atfc_pag_sel_box_text_color']) && $atfc_options['atfc_pag_sel_box_text_color'] != "") ?  $atfc_options['atfc_pag_sel_box_text_color'] : "#FFFFFF";

    $atfc_custom_theme = '<style type="text/css">';

    //Attachment Box Background

    $atfc_custom_theme .= 'ul.atfc_wrapper li{ background: ' . $atfc_box_bg . '; border-color: ' . $atfc_box_border_color . ';}';
    $atfc_custom_theme .= 'ul.atfc_wrapper li:after{ color: ' . $atfc_box_icon_color . ';}';

    //Pagination Box

    $atfc_custom_theme .= '#page_navigation a{ background: ' . $atfc_pag_box_bg . '; border-color: ' . $atfc_pag_border_color . '; color: ' . $atfc_pag_box_text_color . ';}';
    $atfc_custom_theme .= '.active_page{ background: ' . $atfc_pag_sel_box_bg . ' !important; border-color: ' . $atfc_pag_sel_border_color . ' !important; color: ' . $atfc_pag_sel_box_text_color . ' !important;}';


    if (isset($atfc_options['aftc_custom_css']) && $atfc_options['aftc_custom_css'] != "") {

        $atfc_custom_theme .=  $atfc_options['aftc_custom_css'];
    }

    $atfc_custom_theme .= '</style>';



    echo $atfc_custom_scripts . $atfc_custom_theme;
}

add_action('wp_head', 'atfc_custom_scripts');

function atfc_human_filesize($bytes, $decimals = 2)
{
    $size = array('B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB');
    $factor = floor((strlen($bytes) - 1) / 3);
    return sprintf("%.{$decimals}f", $bytes / pow(1024, $factor)) . ' ' . @$size[$factor];
}
