(function($) {

    "use strict";
    
    function atfc_get_item_lists(product_id) {

        return $.ajax({
            type: 'POST',
            url: ajaxurl,
            data: {
                action: 'atfc_get_item_lists_data', // this is the name of our WP AJAX function that we'll set up next
                product_id: product_id
            },
            dataType: 'JSON'
        });
    }
    
    function atfc_data_table() {

            var atfc_products = $atfc_products.val(),
                    atfc_attachment_title = $atfc_attachment_title.val(),
                    atfc_custom_date_range = $atfc_custom_date_range.is(':checked'),
                    atfc_filter_start_date = $atfc_filter_start_date.val(),
                    atfc_filter_end_date = $atfc_filter_end_date.val();

            var oTable = $('#callback-lists-table').dataTable();
            oTable.fnDestroy();


            $('#callback-lists-table').removeClass('dn');

            $('#callback-lists-table').dataTable({
                'bProcessing': true,
                'bServerSide': false,
                'sAjaxSource': ajaxurl + '?action=atfc_download_stats',
                "sServerMethod": "POST",
                "aaSorting": [[0, "desc"]],
                "fnServerParams": function(aoData) {
                    aoData.push({"name": "product_id", "value": atfc_products},
                    {"name": "atfc_id", "value": atfc_attachment_title},
                    {"name": "product_title", "value": $("#atfc_products option:selected").text()},
                    {"name": "atfc_title", "value": $("#atfc_attachment_title option:selected").text()},
                    {"name": "atfc_custom_date_range", "value": atfc_custom_date_range},
                    {"name": "atfc_filter_start_date", "value": atfc_filter_start_date},
                    {"name": "atfc_filter_end_date", "value": atfc_filter_end_date}
                    );
                }
            });

        }

    /*--- Vote Reporting ---*/

    if ($('#atfc_voting_report_page').length) {

        var $atfc_ctrl_section = $('.ctrl-section'),
                $atfc_products = $atfc_ctrl_section.find("#atfc_products"),
                $atfc_attachment_title = $atfc_ctrl_section.find("#atfc_attachment_title"),
                $mv_post_filters = $atfc_ctrl_section.find("#mv_post_filters"),
                $mv_vote_info_type = $atfc_ctrl_section.find("#mv_vote_info_type"),
                $atfc_custom_date_range = $atfc_ctrl_section.find("#atfc_custom_date_range"),
                $atfc_filter_start_date = $atfc_ctrl_section.find("#atfc_filter_start_date"),
                $atfc_filter_end_date = $atfc_ctrl_section.find("#atfc_filter_end_date"),
                $mv_atfc_go = $("#mv_atfc_go"),
                $atfc_download_report = $("#atfc_download_report"),
                $atfc_admin_loader = $("#atfc-admin-loader");

        var $atfc_ctrl_items = $([]).add($atfc_attachment_title).add($mv_post_filters).add($mv_vote_info_type).add($atfc_custom_date_range).add($atfc_filter_start_date).add($atfc_filter_end_date).add($mv_atfc_go).add($atfc_download_report);
        $atfc_products.val("");
        $mv_post_filters.val("");
        $mv_vote_info_type.val(1);
        $atfc_ctrl_items.attr('disabled', 'disabled');


        /*--- Date Range Filter ---*/
  
        var $atfc_date_range_items = $([]).add($atfc_filter_start_date).add($atfc_filter_end_date);

        $atfc_custom_date_range.prop("checked", false);
        $atfc_date_range_items.val("");

        $atfc_custom_date_range.on('click', function() {

            if ($atfc_custom_date_range.is(':checked')) {
                $atfc_date_range_items.val("").removeAttr('disabled');
            } else {
                $atfc_date_range_items.val("").attr('disabled', 'disabled');
            }

        });

        // Filter Start Date.

        $atfc_filter_start_date.datepicker({
            defaultDate: "+1w",
            changeMonth: true,
            dateFormat: 'yy-mm-dd',
            numberOfMonths: 1,
            onSelect: function(selectedDate) {

                $atfc_filter_end_date.datepicker("option", "minDate", selectedDate);

            }
        });

        $atfc_filter_end_date.datepicker({
            defaultDate: "+1w",
            changeMonth: true,
            dateFormat: 'yy-mm-dd',
            numberOfMonths: 1,
            onSelect: function(selectedDate) {

                $atfc_filter_start_date.datepicker({maxDate: selectedDate});

            }
        });

        var $atfc_msg_container = $("#atfc_msg_container"),
                $atfc_attachment_title_default_option_value = $("#atfc_attachment_title").find("option:first");
        $atfc_msg_container.html("");

        

        $atfc_products.on('change', function() {

            var product_id = $(this).val();

            $atfc_admin_loader.removeClass('dn').addClass('dib');

            if (product_id == "") {

                $atfc_admin_loader.removeClass('dib').addClass('dn');
                $atfc_ctrl_items.attr('disabled', 'disabled');
                return false;
            }

            $atfc_attachment_title.attr('disabled', 'disabled');

            $.when(atfc_get_item_lists(product_id)).done(function(response_data) {

                $atfc_admin_loader.removeClass('dib').addClass('dn');

                atfc_data_table();

                if (response_data.status == 1) {

                    $atfc_attachment_title.html($atfc_attachment_title_default_option_value);

                    var posts = '';

                    $.each(response_data.data, function(index, data) {

                        posts += '<option value="' + data['atfc_id'] + '">' + data['atfc_title'] + '</option>';

                    });

                    $atfc_attachment_title.find("option:first").after(posts);
                    $atfc_attachment_title.removeAttr('disabled');
                    $atfc_ctrl_items.removeAttr('disabled');


                } else {
                    $atfc_attachment_title.html($atfc_attachment_title_default_option_value);
                    $atfc_ctrl_items.attr('disabled', 'disabled');
                }

            });

        });



        // On Post Change We Will Remove Disable of Buttons.

        $atfc_attachment_title.on('change', function() {

            var post_title = $(this).val();

            if (post_title == "") {
                atfc_data_table();
                return false;
            }

            $atfc_ctrl_items.removeAttr('disabled');
            $atfc_date_range_items.attr('disabled', 'disabled');

            atfc_data_table();

        });

        // On change Voting Filter Type.

        $mv_post_filters.on('change', function() {

            atfc_data_table();

        });

        // On change Voting Info Type.

        $mv_vote_info_type.on('change', function() {

            atfc_data_table();

        });

        // Go Events.

        $mv_atfc_go.on('click', function() {

            atfc_data_table();

        });

        

        $(document).on("click", "#atfc_reset_report", function() {

            $atfc_products.val("");
            $atfc_admin_loader.removeClass('dib').addClass('dn');
            $atfc_ctrl_items.attr('disabled', 'disabled');
            atfc_data_table();
            return false;

        });

    }

})(jQuery);